package
Version:
v0.0.0-...-4c4b7df
Opens a new window with list of versions in this module.
Published: May 7, 2019
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
-
func AddEditUser(id int64, login, email, pwd1, pwd2 string, admin, moderator bool) error
-
func GetAllUser() ([]model.User, error)
-
func GetUser(id int64) (*model.User, error)
-
func Login(loginEmail, pwd string) (*model.User, error)
-
func RemoveUser(id int64) error
Source Files
¶
- addEdit.go
- get.go
- login.go
- remove.go
Click to show internal directories.
Click to hide internal directories.